netapp_ontap.models.data_collection_metrics_counts_by_state API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.data_collection_metrics_counts_by_state`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DataCollectionMetricsCountsByStateSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DataCollectionMetricsCountsByState object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `count: Size GET POST PATCH`

    The number of data collections in the given state.

    Example: 50

  `state: str GET POST PATCH`

    State of the data collection:

    - draft - The data collection is in draft.
    - processing - The data collection is being processed.
    - published - The data collection is published.
    - failed - The data collection has a failure.
    - outdated - The data collection is outdated.
    - deleted - The data collection has been marked for deletion.

    Valid choices:

    - draft
    - processing
    - published
    - failed
    - outdated
    - deleted